==> owncloud-10.0.3.tgz: owncloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server met server delen is niet geactiveerd op deze server",
    "The mountpoint name contains invalid characters." : "De naam van het mountpoint bevat ongeldige karakters.",
    "Not allowed to create a federated share with the same user server" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "Invalid or untrusted SSL certificate" : "Ongeldig of onvertrouwd SSL-certificaat",
    "Could not authenticate to remote share, password might be wrong" : "Kon niet authenticeren bij externe share, misschien verkeerd wachtwoord",
    "Storage not valid" : "Opslag ongeldig",
    "Couldn't add remote share" : "Kon geen externe share toevoegen",
    "Shared with you" : "Gedeeld met u",
    "Shared with others" : "Gedeeld door u",
    "Shared by link" : "Gedeeld via een link",
    "Uploading..." : "Uploading...",
    "Nothing shared with you yet" : "Nog niets met u gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met u delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die u deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die u via links deelt, worden hier getoond",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Wilt u de externe share {name} van {owner}@{remote} toevoegen?",
    "Remote share" : "Externe share",
    "Remote share password" : "Wachtwoord externe share",
    "Cancel" : "Annuleren",
    "Add remote share" : "Toevoegen externe share",
    "You can upload into this folder" : "U kunt uploaden naar deze map",
    "No ownCloud installation (7 or higher) found at {remote}" : "Geen recente ownCloud installatie (7 of hoger) gevonden op {remote}",
    "Invalid ownCloud url" : "Ongeldige ownCloud url",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
    "Could not delete share" : "Kon share niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "Unknown share type" : "Onbekend type share",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kon pad niet blokkeren",
    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter gegeven",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "U ontving een nieuwe externe share %2$s van %1$s",
    "You received a new remote share from %s" : "U ontving een nieuwe externe share van %s",
    "%1$s accepted remote share %2$s" : "%1$s accepteerde externe share %2$s",
    "%1$s declined remote share %2$s" : "%1$s weigerde externe share %2$s",
    "%1$s unshared %2$s from you" : "%1$s stopte met delen met u van %2$s",
    "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
    "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
    "You shared %1$s with %2$s" : "U deelde %1$s met %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s deelde %1$s met %3$s",
    "You removed the share of %2$s for %1$s" : "U heeft de share van %1$s met %2$s verwijderd",
    "%2$s removed the share of %3$s for %1$s" : "%2$s heeft de share van %1$s met %3$s verwijderd",
    "You shared %1$s with group %2$s" : "U deelde %1$s met groep %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s deelde %1$s met groep %3$s",
    "You removed the share of group %2$s for %1$s" : "U heeft de share van %1$s met de groep %2$s verwijderd",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s heeft de share van %1$s met de groep %3$s verwijderd",
    "%2$s shared %1$s via link" : "%2$s deelde %1$s via link",
    "You shared %1$s via link" : "U deelde %1$s via link",
    "You removed the public link for %1$s" : "U heeft de openbare link voor %1$s verwijderd",
    "%2$s removed the public link for %1$s" : "%2$s heeft de openbare link voor %1$s verwijderd",
    "Your public link for %1$s expired" : "Uw openbare link voor %1$s is verlopen",
    "The public link of %2$s for %1$s expired" : "De openbare link van %2$s voor %1$s is verlopen",
    "%2$s shared %1$s with you" : "%2$s deelde %1$s met u",
    "%2$s removed the share for %1$s" : "%2$s heeft de share van %1$s verwijderd",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Shared with %2$s" : "Gedeeld met %2$s",
    "Shared with %3$s by %2$s" : "Gedeeld met %3$s door %2$s",
    "Removed share for %2$s" : "Share van %2$s verwijderd",
    "%2$s removed share for %3$s" : "%2$s verwijderde de share van %3$s",
    "Shared with group %2$s" : "Gedeeld met groep %2$s",
    "Shared with group %3$s by %2$s" : "Gedeeld met groep %3$s door %2$s",
    "Removed share of group %2$s" : "Share van de groep %2$s verwijderd",
    "%2$s removed share of group %3$s" : "%2$s verwijderde share met groep %3$s",
    "Shared via link by %2$s" : "Gedeeld via link door %2$s",
    "Shared via public link" : "Gedeeld via een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "%2$s removed public link" : "%2$s verwijderede openbare link",
    "Public link expired" : "Openbare link is verlopen",
    "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
    "Shared by %2$s" : "Gedeeld door %2$s",
    "Shares" : "Gedeeld",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatum",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "Add to your ownCloud" : "Toevoegen aan uw ownCloud",
    "Download" : "Downloaden",
    "Download %s" : "Download %s",
    "Direct link" : "Directe link"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/nl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server met server delen is niet geactiveerd op deze server",
    "The mountpoint name contains invalid characters." : "De naam van het mountpoint bevat ongeldige karakters.",
    "Not allowed to create a federated share with the same user server" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "Invalid or untrusted SSL certificate" : "Ongeldig of onvertrouwd SSL-certificaat",
    "Could not authenticate to remote share, password might be wrong" : "Kon niet authenticeren bij externe share, misschien verkeerd wachtwoord",
    "Storage not valid" : "Opslag ongeldig",
    "Couldn't add remote share" : "Kon geen externe share toevoegen",
    "Shared with you" : "Gedeeld met u",
    "Shared with others" : "Gedeeld door u",
    "Shared by link" : "Gedeeld via een link",
    "Uploading..." : "Uploading...",
    "Nothing shared with you yet" : "Nog niets met u gedeeld",
    "Files and folders others share with you will show up here" : "Bestanden en mappen die anderen met u delen, worden hier getoond",
    "Nothing shared yet" : "Nog niets gedeeld",
    "Files and folders you share will show up here" : "Bestanden en mappen die u deelt, worden hier getoond",
    "No shared links" : "Geen gedeelde links",
    "Files and folders you share by link will show up here" : "Bestanden en mappen die u via links deelt, worden hier getoond",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Wilt u de externe share {name} van {owner}@{remote} toevoegen?",
    "Remote share" : "Externe share",
    "Remote share password" : "Wachtwoord externe share",
    "Cancel" : "Annuleren",
    "Add remote share" : "Toevoegen externe share",
    "You can upload into this folder" : "U kunt uploaden naar deze map",
    "No ownCloud installation (7 or higher) found at {remote}" : "Geen recente ownCloud installatie (7 of hoger) gevonden op {remote}",
    "Invalid ownCloud url" : "Ongeldige ownCloud url",
    "Share" : "Deel",
    "No expiration date set" : "Geen vervaldatum ingesteld",
    "Shared by" : "Gedeeld door",
    "Sharing" : "Delen",
    "Share API is disabled" : "Delen API is uitgeschakeld",
    "Wrong share ID, share doesn't exist" : "Onjuist deel-ID, de share bestaat niet",
    "Could not delete share" : "Kon share niet verwijderen",
    "Please specify a file or folder path" : "Geef een bestand of pad van een map op",
    "Wrong path, file/folder doesn't exist" : "Onjuist pad, bestand/map bestaat niet",
    "Please specify a valid user" : "Geef een geldige gebruiker op",
    "Group sharing is disabled by the administrator" : "Delen voor groepen is uitgeschakeld door de beheerder",
    "Please specify a valid group" : "Geef een geldige groep op",
    "Public link sharing is disabled by the administrator" : "Delen van openbare links is uitgeschakeld door de beheerder",
    "Public upload disabled by the administrator" : "Publieke upload uitgeschakeld door de systeembeheerder",
    "Public upload is only possible for publicly shared folders" : "Publieke upload is alleen mogelijk voor publiek gedeelde mappen",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, datumnotatie moet in de vorm YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Delen van %s mislukte omdat de backend het delen van type %s niet ondersteunt",
    "Unknown share type" : "Onbekend type share",
    "Not a directory" : "Geen directory",
    "Could not lock path" : "Kon pad niet blokkeren",
    "Can't change permissions for public share links" : "Kan permissies voor openbare share links niet wijzigen",
    "Wrong or no update parameter given" : "Verkeerde of geen update parameter gegeven",
    "Cannot increase permissions" : "Kan de rechten niet verruimen",
    "A file or folder has been <strong>shared</strong>" : "Een bestand of map is <strong>gedeeld</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Een bestand of map werd gedeeld vanaf <strong>een andere server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Een openbaar gedeeld bestand of map werd <strong>gedownloaded</strong>",
    "You received a new remote share %2$s from %1$s" : "U ontving een nieuwe externe share %2$s van %1$s",
    "You received a new remote share from %s" : "U ontving een nieuwe externe share van %s",
    "%1$s accepted remote share %2$s" : "%1$s accepteerde externe share %2$s",
    "%1$s declined remote share %2$s" : "%1$s weigerde externe share %2$s",
    "%1$s unshared %2$s from you" : "%1$s stopte met delen met u van %2$s",
    "Public shared folder %1$s was downloaded" : "Openbaar gedeelde map %1$s werd gedownloaded",
    "Public shared file %1$s was downloaded" : "Openbaar gedeeld bestand %1$s werd gedownloaded",
    "You shared %1$s with %2$s" : "U deelde %1$s met %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s deelde %1$s met %3$s",
    "You removed the share of %2$s for %1$s" : "U heeft de share van %1$s met %2$s verwijderd",
    "%2$s removed the share of %3$s for %1$s" : "%2$s heeft de share van %1$s met %3$s verwijderd",
    "You shared %1$s with group %2$s" : "U deelde %1$s met groep %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s deelde %1$s met groep %3$s",
    "You removed the share of group %2$s for %1$s" : "U heeft de share van %1$s met de groep %2$s verwijderd",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s heeft de share van %1$s met de groep %3$s verwijderd",
    "%2$s shared %1$s via link" : "%2$s deelde %1$s via link",
    "You shared %1$s via link" : "U deelde %1$s via link",
    "You removed the public link for %1$s" : "U heeft de openbare link voor %1$s verwijderd",
    "%2$s removed the public link for %1$s" : "%2$s heeft de openbare link voor %1$s verwijderd",
    "Your public link for %1$s expired" : "Uw openbare link voor %1$s is verlopen",
    "The public link of %2$s for %1$s expired" : "De openbare link van %2$s voor %1$s is verlopen",
    "%2$s shared %1$s with you" : "%2$s deelde %1$s met u",
    "%2$s removed the share for %1$s" : "%2$s heeft de share van %1$s verwijderd",
    "Downloaded via public link" : "Gedownload via een openbare link",
    "Shared with %2$s" : "Gedeeld met %2$s",
    "Shared with %3$s by %2$s" : "Gedeeld met %3$s door %2$s",
    "Removed share for %2$s" : "Share van %2$s verwijderd",
    "%2$s removed share for %3$s" : "%2$s verwijderde de share van %3$s",
    "Shared with group %2$s" : "Gedeeld met groep %2$s",
    "Shared with group %3$s by %2$s" : "Gedeeld met groep %3$s door %2$s",
    "Removed share of group %2$s" : "Share van de groep %2$s verwijderd",
    "%2$s removed share of group %3$s" : "%2$s verwijderde share met groep %3$s",
    "Shared via link by %2$s" : "Gedeeld via link door %2$s",
    "Shared via public link" : "Gedeeld via een openbare link",
    "Removed public link" : "Openbare link verwijderd",
    "%2$s removed public link" : "%2$s verwijderede openbare link",
    "Public link expired" : "Openbare link is verlopen",
    "Public link of %2$s expired" : "Openbare link van %2$s is verlopen",
    "Shared by %2$s" : "Gedeeld door %2$s",
    "Shares" : "Gedeeld",
    "This share is password-protected" : "Deze share is met een wachtwoord beveiligd",
    "The password is wrong. Try again." : "Wachtwoord ongeldig. Probeer het nogmaals.",
    "Password" : "Wachtwoord",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Name" : "Naam",
    "Share time" : "Deel tijd",
    "Expiration date" : "Vervaldatum",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, deze link lijkt niet meer in gebruik te zijn.",
    "Reasons might be:" : "Redenen kunnen zijn:",
    "the item was removed" : "bestand was verwijderd",
    "the link expired" : "de link is verlopen",
    "sharing is disabled" : "delen is uitgeschakeld",
    "For more info, please ask the person who sent this link." : "Voor meer informatie, neem contact op met de persoon die u deze link heeft gestuurd.",
    "%s is publicly shared" : "%s is openbaar gedeeld",
    "Add to your ownCloud" : "Toevoegen aan uw ownCloud",
    "Download" : "Downloaden",
    "Download %s" : "Download %s",
    "Direct link" : "Directe link",
    "Anonymous upload" : "Anonieme upload",
    "Uploaded files" : "Geüploade bestanden",
    "Click to select files or use drag & drop to upload" : "Klik om bestanden te selecteren of gebruik drag&drop om te uploaden",
    "Cannot remove all permissions" : "Kan niet alle rechten verwijderen",
    "Pending" : "In behandeling",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Declined" : "Afgewezen",
    "Accept Share" : "Share accepteren",
    "Decline Share" : "Share afwijzen",
    "The group is blacklisted for sharing" : "Deze groep is uitgesloten voor delen",
    "Only recipient can change accepted state" : "Alleen de ontvanger kan de geaccepteerde status wijzigen",
    "State" : "Status",
    "Exclude groups from receiving shares." : "Groepen uitsluiten van het ontvangen van shares.",
    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "Deze groepen zullen geen shares meer ontvangen. Leden van deze groep kunnen nog wel shares verzenden en ontvangen buiten deze groep om."
},
"nplurals=2; plural=(n != 1);");
